@@ -25,9 +25,9 @@
 set -e
 
 VER2=2.8.17
-VER3=3.8.9
-VER3X=3080900
-VERZ=1.2.7
+VER3=3.13.0
+VER3X=3130000
+VERZ=1.2.8
 TCCVER=0.9.26
 
 nov2=false
@@ -89,6 +89,7 @@ $nov2 || test -r sqlite-${VER2}.tar.gz || \
 $nov2 || test -r sqlite-${VER2}.tar.gz || exit 1
 
 $nov2 || rm -f sqlite
+$nov2 || rm -rf sqlite-${VER2}
 $nov2 || tar xzf sqlite-${VER2}.tar.gz
 $nov2 || ln -sf sqlite-${VER2} sqlite
 
@@ -306,7 +307,7 @@ EOD
 # use open file dialog when no database name given
 # need to link with -lcomdlg32 when enabled
 true || patch sqlite3/src/shell.c <<'EOD'
---- sqlite3.orig/src/shell.c        2006-06-06 14:32:21.000000000 +0200
+--- sqlite3.orig/src/shell.c       2006-06-06 14:32:21.000000000 +0200
 +++ sqlite3/src/shell.c     2006-07-23 11:04:50.000000000 +0200
 @@ -21,6 +21,10 @@
  #include <ctype.h>
@@ -375,6 +376,9 @@ test "$VER3" != "3.7.14" -a "$VER3" != "3.7.14.1" -a "$VER3" != "3.7.15" \
   -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
   -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   -a "$VER3" != "3.8.7" -a "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" \
+  -a "$VER3" != "3.8.10" -a "$VER3" != "3.8.11" -a "$VER3" != "3.9.0" \
+  -a "$VER3" != "3.9.1" -a "$VER3" != "3.9.2" -a "$VER3" != "3.10.0" \
+  -a "$VER3" != "3.10.2" -a "$VER3" != "3.12.2" -a "$VER3" != "3.13.0" \
   && patch sqlite3/src/libshell.c <<'EOD'
 --- sqlite3.orig/src/libshell.c  2007-01-08 23:40:05.000000000 +0100
 +++ sqlite3/src/libshell.c  2007-01-10 18:35:43.000000000 +0100
@@ -511,7 +515,9 @@ test "$VER3" = "3.7.15" -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" \
  #else
 EOD
 
-test "$VER3" = "3.8.9" \
+test "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" \
+  -o "$VER3" = "3.9.0" -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" \
+  -o "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" \
   && patch sqlite3/src/libshell.c <<'EOD'
 --- sqlite3.orig/src/libshell.c  2012-12-12 14:42:10.000000000 +0100
 +++ sqlite3/src/libshell.c  2012-12-13 12:14:57.000000000 +0100
@@ -555,6 +561,66 @@ test "$VER3" = "3.8.9" \
  #else
 EOD
 
+test "$VER3" = "3.13.0" \
+  && patch sqlite3/src/libshell.c <<'EOD'
+--- sqlite3.orig/src/libshell.c.orig	2016-05-18 13:06:59.000000000 +0200
++++ sqlite3/src/libshell.c	2016-06-04 17:02:05.000000000 +0200
+@@ -53,6 +53,10 @@
+ #include <ctype.h>
+ #include <stdarg.h>
+ 
++#ifdef _WIN32
++#include <windows.h>
++#endif
++
+ #if !defined(_WIN32) && !defined(WIN32)
+ # include <signal.h>
+ # if !defined(__RTP__) && !defined(_WRS_KERNEL)
+@@ -5195,20 +5199,9 @@
+   return argv[i];
+ }
+ 
+-#ifndef SQLITE_SHELL_IS_UTF8
+-#  if (defined(_WIN32) || defined(WIN32)) && defined(_MSC_VER)
+-#    define SQLITE_SHELL_IS_UTF8          (0)
+-#  else
+-#    define SQLITE_SHELL_IS_UTF8          (1)
+-#  endif
+-#endif
++#define SQLITE_SHELL_IS_UTF8          (1)
+ 
+-#if SQLITE_SHELL_IS_UTF8
+-int SQLITE_CDECL main(int argc, char **argv){
+-#else
+-int SQLITE_CDECL wmain(int argc, wchar_t **wargv){
+-  char **argv;
+-#endif
++int sqlite3_main(int argc, char **argv){
+   char *zErrMsg = 0;
+   ShellState data;
+   const char *zInitFile = 0;
+@@ -5375,6 +5368,19 @@
+     }
+   }
+   if( data.zDbFilename==0 ){
++#if defined(_WIN32) && !defined(__TINYC__)
++    static OPENFILENAME ofn;
++    static char zDbFn[1024];
++    ofn.lStructSize = sizeof(ofn);
++    ofn.lpstrFile = (LPTSTR) zDbFn;
++    ofn.nMaxFile = sizeof(zDbFn);
++    ofn.Flags = OFN_PATHMUSTEXIST | OFN_EXPLORER | OFN_NOCHANGEDIR;
++    if ( GetOpenFileName(&ofn) ){
++      data.zDbFilename = zDbFn;
++    }
++  }
++  if( data.zDbFilename==0 ){
++#endif
+ #ifndef SQLITE_OMIT_MEMORYDB
+     data.zDbFilename = ":memory:";
+     warnInmemoryDb = argc==1;
+EOD
+
 rm -f sqlite3/src/minshell.c
 touch sqlite3/src/minshell.c
 patch sqlite3/src/minshell.c <<'EOD'
@@ -584,7 +650,8 @@ patch sqlite3/src/minshell.c <<'EOD'
 EOD
 
 # amalgamation: add libshell.c 
-test "$VER3" != "3.5.6" && test -r sqlite3/tool/mksqlite3c.tcl && patch -d sqlite3 -p1 <<'EOD'
+test "$VER3" != "3.5.6" && test -r sqlite3/tool/mksqlite3c.tcl && \
+  patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/tool/mksqlite3c.tcl	2007-04-02 14:20:10.000000000 +0200
 +++ sqlite3/tool/mksqlite3c.tcl	2007-04-03 09:42:03.000000000 +0200
 @@ -194,6 +194,7 @@
@@ -596,7 +663,8 @@ test "$VER3" != "3.5.6" && test -r sqlite3/tool/mksqlite3c.tcl && patch -d sqlit
     tokenize.c
     complete.c
 EOD
-test "$VER3" = "3.5.6" && test -r sqlite3/tool/mksqlite3c.tcl && patch -d sqlite3 -p1 <<'EOD'
+test "$VER3" = "3.5.6" && test -r sqlite3/tool/mksqlite3c.tcl && \
+  patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/tool/mksqlite3c.tcl	2007-04-02 14:20:10.000000000 +0200
 +++ sqlite3/tool/mksqlite3c.tcl	2007-04-03 09:42:03.000000000 +0200
 @@ -200,6 +200,7 @@
@@ -627,6 +695,9 @@ test "$VER3" != "3.6.15" -a "$VER3" != "3.6.16" -a "$VER3" != "3.6.17" \
   -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
   -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   -a "$VER3" != "3.8.7" -a "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" \
+  -a "$VER3" != "3.8.10" -a "$VER3" != "3.8.11" -a "$VER3" != "3.9.0" \
+  -a "$VER3" != "3.9.1" -a "$VER3" != "3.9.2" -a "$VER3" != "3.10.0" \
+  -a "$VER3" != "3.10.2" -a "$VER3" != "3.12.2" -a "$VER3" != "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 diff -u sqlite3.orig/src/build.c sqlite3/src/build.c
 --- sqlite3.orig/src/build.c	2007-01-09 14:53:04.000000000 +0100
@@ -685,14 +756,17 @@ diff -u sqlite3.orig/src/vtab.c sqlite3/src/vtab.c
 EOD
 
 # patch: re-enable NO_TCL in tclsqlite.c (3.3.15)
-test "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" \
+test "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" -a "$VER3" != "3.8.10" \
+  -a "$VER3" != "3.8.11" -a "$VER3" != "3.9.0" -a "$VER3" != "3.9.1" \
+  -a "$VER3" != "3.9.2" -a "$VER3" != "3.10.0" -a "$VER3" != "3.10.2" \
+  -a "$VER3" != "3.12.2" -a "$VER3" != "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 diff -u sqlite3.orig/src/tclsqlite.c sqlite3/src/tclsqlite.c
 --- sqlite3.orig/src/tclsqlite.c	2007-04-06 17:02:14.000000000 +0200
 +++ sqlite3/src/tclsqlite.c	2007-04-10 07:47:49.000000000 +0200
 @@ -14,6 +14,7 @@
  **
- ** $Id: mingw-cross-build.sh,v 1.95 2015/04/12 14:09:48 chw Exp chw $
+ ** $Id: mingw-cross-build.sh,v 1.103 2016/06/04 16:20:37 chw Exp chw $
  */
 +#ifndef NO_TCL     /* Omit this whole file if TCL is unavailable */
  #include "tcl.h"
@@ -706,7 +780,10 @@ diff -u sqlite3.orig/src/tclsqlite.c sqlite3/src/tclsqlite.c
 +#endif /* !defined(NO_TCL) */
 EOD
 
-test "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
+test "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" \
+  -o "$VER3" = "3.8.11" -o "$VER3" = "3.9.0" -o "$VER3" = "3.9.1" \
+  -o "$VER3" = "3.9.2" -o "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" \
+  -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/tclsqlite.c    2015-01-16 14:47:26.000000000 +0100
 +++ sqlite3/src/tclsqlite.c 2015-01-19 17:56:26.517386413 +0100
@@ -874,6 +951,9 @@ test "$VER3" != "3.6.21" -a "$VER3" != "3.6.22" -a "$VER3" != "3.6.23" \
   -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
   -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   -a "$VER3" != "3.8.7" -a "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" \
+  -a "$VER3" != "3.8.10" -a "$VER3" != "3.8.11" -a "$VER3" != "3.9.0" \
+  -a "$VER3" != "3.9.1" -a "$VER3" != "3.9.2" -a "$VER3" != "3.10.0" \
+  -a "$VER3" != "3.10.2" -a "$VER3" != "3.12.2" -a "$VER3" != "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c 2008-02-02 17:24:34.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c      2008-03-16 11:29:02.000000000 +0100
@@ -966,7 +1046,10 @@ test "$VER3" != "3.7.8" -a "$VER3" != "3.7.9" -a "$VER3" != "3.7.10" \
   -a "$VER3" != "3.8.2" -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" \
   -a "$VER3" != "3.8.4.1" -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" \
   -a "$VER3" != "3.8.6" -a "$VER3" != "3.8.7" -a "$VER3" != "3.8.8" \
-  -a "$VER3" != "3.8.9" \
+  -a "$VER3" != "3.8.9" -a "$VER3" != "3.8.10" -a "$VER3" != "3.8.11" \
+  -a "$VER3" != "3.9.0" -a "$VER3" != "3.9.1" -a "$VER3" != "3.9.2" \
+  -a "$VER3" != "3.10.0" -a "$VER3" != "3.10.2" -a "$VER3" != "3.12.2" \
+  -a "$VER3" != "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_hash.c    2007-11-24 01:41:52.000000000 +0100
 +++ sqlite3/ext/fts3/fts3_hash.c 2008-03-16 11:39:57.000000000 +0100
@@ -981,6 +1064,7 @@ test "$VER3" != "3.7.8" -a "$VER3" != "3.7.9" -a "$VER3" != "3.7.10" \
 +
  #include "sqlite3.h"
  #include "fts3_hash.h"
+ 
 EOD
 test "$VER3" = "3.6.21" && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_write.c   2009-12-03 20:39:06.000000000 +0100
@@ -1272,7 +1356,7 @@ test "$VER3" = "3.6.8" -o "$VER3" = "3.6.9" -o "$VER3" = "3.6.10" \
   -o "$VER3" = "3.6.11" -o "$VER3" = "3.6.12" -o "$VER3" = "3.6.13" \
   -o "$VER3" = "3.6.14" -o "$VER3" = "3.6.14.1" -o "$VER3" = "3.6.14.2" \
   -o "$VER3" = "3.6.15" -o "$VER3" = "3.6.16" -o "$VER3" = "3.6.17" \
-  -o "$VER3" = "3.6.18" -o "$VER3" = "3.6.19" -o "$VER3" = "3.6.20" &&
+  -o "$VER3" = "3.6.18" -o "$VER3" = "3.6.19" -o "$VER3" = "3.6.20" && \
   patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_expr.c	2009-01-01 15:06:13.000000000 +0100
 +++ sqlite3/ext/fts3/fts3_expr.c	2009-01-14 09:55:13.000000000 +0100
@@ -1309,6 +1393,9 @@ test "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" -a "$VER3" != "3.8.2" \
   -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
   -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   -a "$VER3" != "3.8.7" -a "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" \
+  -a "$VER3" != "3.8.10" -a "$VER3" != "3.8.11" -a "$VER3" != "3.9.0" \
+  -a "$VER3" != "3.9.1" -a "$VER3" != "3.9.2" -a "$VER3" != "3.10.0" \
+  -a "$VER3" != "3.10.2" -a "$VER3" != "3.12.2" -a "$VER3" != "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/rtree/rtree.c	2008-07-16 16:43:35.000000000 +0200
 +++ sqlite3/ext/rtree/rtree.c	2008-07-17 08:59:53.000000000 +0200
@@ -1386,6 +1473,9 @@ test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" -o "$VER3" = "3.8.4.1" \
   -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" -o "$VER3" = "3.8.6" \
   -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" -o "$VER3" = "3.9.0" \
+  -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" -o "$VER3" = "3.10.0" \
+  -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_aux.c	2011-06-24 09:06:08.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_aux.c	2011-06-25 06:44:08.000000000 +0200
@@ -1435,7 +1525,10 @@ test "$VER3" = "3.7.8" -o "$VER3" = "3.7.9" -o "$VER3" = "3.7.10" \
   -o "$VER3" = "3.8.2" -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" \
   -o "$VER3" = "3.8.4.1" -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" \
   -o "$VER3" = "3.8.6" -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" \
-  -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" \
+  -o "$VER3" = "3.9.0" -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" \
+  -o "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" \
+  -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c	2011-09-19 20:46:52.000000000 +0200
 +++ sqlite3/ext/fts3/fts3.c	2011-09-20 09:47:40.000000000 +0200
@@ -1470,6 +1563,9 @@ test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" -o "$VER3" = "3.8.4.1" \
   -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" -o "$VER3" = "3.8.6" \
   -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" -o "$VER3" = "3.9.0" \
+  -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" -o "$VER3" = "3.10.0" \
+  -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_expr.c	2011-06-24 09:06:08.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_expr.c	2011-06-25 06:47:00.000000000 +0200
@@ -1625,12 +1721,19 @@ test "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" -o "$VER3" = "3.8.2" \
   -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" -o "$VER3" = "3.8.4.1" \
   -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" -o "$VER3" = "3.8.6" \
   -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" -o "$VER3" = "3.9.0" \
+  -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" -o "$VER3" = "3.10.0" \
+  -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/loadext.c       2013-09-16 06:56:48.000000000 +0200
 +++ sqlite3/src/loadext.c   2013-09-16 06:58:14.000000000 +0200
-@@ -495,7 +495,8 @@
+@@ -495,7 +495,12 @@
      memcpy(zAltEntry, "sqlite3_", 8);
++#if SQLITE_OS_WIN
++    for(iFile=ncFile-1; iFile>=0 && zFile[iFile]!='/' && zFile[iFile]!='\\'; iFile--){}
++#else
      for(iFile=ncFile-1; iFile>=0 && zFile[iFile]!='/'; iFile--){}
++#endif
      iFile++;
 -    if( sqlite3_strnicmp(zFile+iFile, "lib", 3)==0 ) iFile += 3;
 +    if( sqlite3_strnicmp(zFile+iFile, "sqlite3_mod_", 12)==0 ) iFile += 12;
@@ -1644,7 +1747,10 @@ EOD
 test "$VER3" = "3.8.2" -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" \
   -o "$VER3" = "3.8.4.1" -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" \
   -o "$VER3" = "3.8.6" -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" \
-  -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" \
+  -o "$VER3" = "3.9.0" -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" \
+  -o "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" \
+  -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c      2014-03-26 10:26:28.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c  2014-03-26 16:54:39.000000000 +0100
@@ -1661,6 +1767,9 @@ EOD
 
 # missing windows.h for DWORD, HANDLE in threads.c
 test "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" -o "$VER3" = "3.9.0" \
+  -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" -o "$VER3" = "3.10.0" \
+  -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/threads.c      2014-10-17 13:38:27.000000000 +0200
 +++ sqlite3/src/threads.c   2014-10-26 13:40:26.000000000 +0100
@@ -1674,6 +1783,31 @@ test "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
  /* A running thread */
 EOD
 
+# tcl8.4 compatibility for mkfts5c.tcl
+test "$VER3" = "3.9.0" -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" \
+  -o "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" \
+  -o "$VER3" = "3.13.0" \
+  && patch sqlite3/ext/fts5/tool/mkfts5c.tcl <<'EOD'
+--- mkfts5c.tcl.orig	2015-10-14 14:53:26.000000000 +0200
++++ mkfts5c.tcl	2015-10-15 08:19:25.000000000 +0200
+@@ -60,7 +60,8 @@
+ 
+   set L [split [readfile [file join $top manifest]]] 
+   set date [lindex $L [expr [lsearch -exact $L D]+1]]
+-  set date [string range $date 0 [string last . $date]-1]
++  set dend [expr [string last . $date]-1]
++  set date [string range $date 0 $dend]
+   set date [string map {T { }} $date]
+ 
+   return "fts5: $date $uuid"
+EOD
+
+# tcl8.4 compatibility for some tools
+test "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" \
+  -o "$VER3" = "3.13.0" \
+  && perl -pi -e 's/ rb\]/ r\]/g' sqlite3/tool/mkopcodec.tcl \
+      sqlite3/tool/tostr.tcl sqlite3/tool/addopcodes.tcl
+
 echo "===================="
 echo "Preparing TinyCC ..."
 echo "===================="
@@ -1725,7 +1859,7 @@ if test -r sqlite3/sqlite3.c -a -f "$WITH_SEE" ; then
     ADD_CFLAGS="$ADD_CFLAGS -DSEEEXT=\\\"$SEEEXT\\\""
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_API=static -DWIN32=1 -DNDEBUG=1 -DNO_TCL"
     ADD_CFLAGS="$ADD_CFLAGS -DTHREADSAFE=1"
-    ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_DLL=1 -DSQLITE_TRHEADSAFE=1"
+    ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_DLL=1 -DSQLITE_THREADSAFE=1"
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_OS_WIN=1 -DSQLITE_ASCII=1"
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_SOUNDEX=1"
     ADD_CFLAGS="$ADD_CFLAGS -DSQLITE_ENABLE_COLUMN_METADATA=1"
@@ -1736,7 +1870,7 @@ if test -r sqlite3/sqlite3.c -a -f "$WITH_SEE" ; then
     unset SQLITE3_EXE
 fi
 test "$VER3" = "3.8.6" -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" \
-  -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" \
   && patch sqlite3/sqlite3.c <<'EOD'
 --- sqlite3.orig/sqlite3.c      2014-09-14 15:02:38.000000000 +0200
 +++ sqlite3/sqlite3.c   2014-09-14 15:03:02.000000000 +0200
@@ -1750,6 +1884,22 @@ test "$VER3" = "3.8.6" -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" \
  #ifndef access
  # define access(f,m) _access((f),(m))
 EOD
+test "$VER3" = "3.8.11" -o "$VER3" = "3.9.0" -o "$VER3" = "3.9.1" \
+  -o "$VER3" = "3.9.2" -o "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" \
+  -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" \
+  && patch sqlite3/sqlite3.c <<'EOD'
+--- sqlite3.c.orig      2015-09-18 17:17:58.000000000 +0200
++++ sqlite3.c   2015-09-18 17:50:01.000000000 +0200
+@@ -128353,7 +128353,7 @@
+ 
+ #if defined(_WIN32) || defined(WIN32)
+ # include <io.h>
+-/* # include <fcntl.h> */
++# include <fcntl.h>
+ # define isatty(h) _isatty(h)
+ # ifndef access
+ #  define access(f,m) _access((f),(m))
+EOD
 if test -n "$SQLITE_DLLS" ; then
     make -C sqlite3 -f ../mf-sqlite3.mingw-cross sqlite3.dll
 fi
