@@ -23,9 +23,9 @@
 set -e
 
 VER2=2.8.17
-VER3=3.8.9
-VER3X=3080900
-VERZ=1.2.7
+VER3=3.13.0
+VER3X=3130000
+VERZ=1.2.8
 
 nov2=false
 if test -n "$NO_SQLITE2" ; then
@@ -78,6 +78,7 @@ $nov2 || test -r sqlite-${VER2}.tar.gz || \
 $nov2 || test -r sqlite-${VER2}.tar.gz || exit 1
 
 $nov2 || rm -f sqlite
+$nov2 || rm -rf sqlite-${VER2}
 $nov2 || tar xzf sqlite-${VER2}.tar.gz
 $nov2 || ln -sf sqlite-${VER2} sqlite
 
@@ -364,6 +365,9 @@ test "$VER3" != "3.7.14" -a "$VER3" != "3.7.14.1" -a "$VER3" != "3.7.15" \
   -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
   -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   -a "$VER3" != "3.8.7" -a "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" \
+  -a "$VER3" != "3.8.10" -a "$VER3" != "3.8.11" -a "$VER3" != "3.9.0" \
+  -a "$VER3" != "3.9.1" -a "$VER3" != "3.9.2" -a "$VER3" != "3.10.0" \
+  -a "$VER3" != "3.10.2" -a "$VER3" != "3.12.2" -a "$VER3" != "3.13.0" \
   && patch sqlite3/src/libshell.c <<'EOD'
 --- sqlite3.orig/src/libshell.c  2007-01-08 23:40:05.000000000 +0100
 +++ sqlite3/src/libshell.c  2007-01-10 18:35:43.000000000 +0100
@@ -500,7 +504,9 @@ test "$VER3" = "3.7.15" -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" \
  #else
 EOD
 
-test "$VER3" = "3.8.9" \
+test "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" \
+  -o "$VER3" = "3.9.0" -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" \
+  -o "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" \
   && patch sqlite3/src/libshell.c <<'EOD'
 --- sqlite3.orig/src/libshell.c  2012-12-12 14:42:10.000000000 +0100
 +++ sqlite3/src/libshell.c  2012-12-13 12:14:57.000000000 +0100
@@ -544,6 +550,66 @@ test "$VER3" = "3.8.9" \
  #else
 EOD
 
+test "$VER3" = "3.13.0" \
+  && patch sqlite3/src/libshell.c <<'EOD'
+--- sqlite3.orig/src/libshell.c.orig	2016-05-18 13:06:59.000000000 +0200
++++ sqlite3/src/libshell.c	2016-06-04 17:02:05.000000000 +0200
+@@ -53,6 +53,10 @@
+ #include <ctype.h>
+ #include <stdarg.h>
+ 
++#ifdef _WIN32
++#include <windows.h>
++#endif
++
+ #if !defined(_WIN32) && !defined(WIN32)
+ # include <signal.h>
+ # if !defined(__RTP__) && !defined(_WRS_KERNEL)
+@@ -5195,20 +5199,9 @@
+   return argv[i];
+ }
+ 
+-#ifndef SQLITE_SHELL_IS_UTF8
+-#  if (defined(_WIN32) || defined(WIN32)) && defined(_MSC_VER)
+-#    define SQLITE_SHELL_IS_UTF8          (0)
+-#  else
+-#    define SQLITE_SHELL_IS_UTF8          (1)
+-#  endif
+-#endif
++#define SQLITE_SHELL_IS_UTF8          (1)
+ 
+-#if SQLITE_SHELL_IS_UTF8
+-int SQLITE_CDECL main(int argc, char **argv){
+-#else
+-int SQLITE_CDECL wmain(int argc, wchar_t **wargv){
+-  char **argv;
+-#endif
++int sqlite3_main(int argc, char **argv){
+   char *zErrMsg = 0;
+   ShellState data;
+   const char *zInitFile = 0;
+@@ -5375,6 +5368,19 @@
+     }
+   }
+   if( data.zDbFilename==0 ){
++#if defined(_WIN32) && !defined(__TINYC__)
++    static OPENFILENAME ofn;
++    static char zDbFn[1024];
++    ofn.lStructSize = sizeof(ofn);
++    ofn.lpstrFile = (LPTSTR) zDbFn;
++    ofn.nMaxFile = sizeof(zDbFn);
++    ofn.Flags = OFN_PATHMUSTEXIST | OFN_EXPLORER | OFN_NOCHANGEDIR;
++    if ( GetOpenFileName(&ofn) ){
++      data.zDbFilename = zDbFn;
++    }
++  }
++  if( data.zDbFilename==0 ){
++#endif
+ #ifndef SQLITE_OMIT_MEMORYDB
+     data.zDbFilename = ":memory:";
+     warnInmemoryDb = argc==1;
+EOD
+
 rm -f sqlite3/src/minshell.c
 touch sqlite3/src/minshell.c
 patch sqlite3/src/minshell.c <<'EOD'
@@ -573,7 +639,8 @@ patch sqlite3/src/minshell.c <<'EOD'
 EOD
 
 # amalgamation: add libshell.c 
-test "$VER3" != "3.5.6" && test -r sqlite3/tool/mksqlite3c.tcl && patch -d sqlite3 -p1 <<'EOD'
+test "$VER3" != "3.5.6" && test -r sqlite3/tool/mksqlite3c.tcl && \
+  patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/tool/mksqlite3c.tcl	2007-04-02 14:20:10.000000000 +0200
 +++ sqlite3/tool/mksqlite3c.tcl	2007-04-03 09:42:03.000000000 +0200
 @@ -194,6 +194,7 @@
@@ -585,7 +652,8 @@ test "$VER3" != "3.5.6" && test -r sqlite3/tool/mksqlite3c.tcl && patch -d sqlit
     tokenize.c
     complete.c
 EOD
-test "$VER3" = "3.5.6" && test -r sqlite3/tool/mksqlite3c.tcl && patch -d sqlite3 -p1 <<'EOD'
+test "$VER3" = "3.5.6" && test -r sqlite3/tool/mksqlite3c.tcl && \
+  patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/tool/mksqlite3c.tcl	2007-04-02 14:20:10.000000000 +0200
 +++ sqlite3/tool/mksqlite3c.tcl	2007-04-03 09:42:03.000000000 +0200
 @@ -200,6 +200,7 @@
@@ -616,6 +684,9 @@ test "$VER3" != "3.6.15" -a "$VER3" != "3.6.16" -a "$VER3" != "3.6.17" \
   -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
   -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   -a "$VER3" != "3.8.7" -a "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" \
+  -a "$VER3" != "3.8.10" -a "$VER3" != "3.8.11" -a "$VER3" != "3.9.0" \
+  -a "$VER3" != "3.9.1" -a "$VER3" != "3.9.2" -a "$VER3" != "3.10.0" \
+  -a "$VER3" != "3.10.2" -a "$VER3" != "3.12.2" -a "$VER3" != "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 diff -u sqlite3.orig/src/build.c sqlite3/src/build.c
 --- sqlite3.orig/src/build.c	2007-01-09 14:53:04.000000000 +0100
@@ -674,14 +745,17 @@ diff -u sqlite3.orig/src/vtab.c sqlite3/src/vtab.c
 EOD
 
 # patch: re-enable NO_TCL in tclsqlite.c (3.3.15)
-test "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" \
+test "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" -a "$VER3" != "3.8.10" \
+  -a "$VER3" != "3.8.11" -a "$VER3" != "3.9.0" -a "$VER3" != "3.9.1" \
+  -a "$VER3" != "3.9.2" -a "$VER3" != "3.10.0" -a "$VER3" != "3.10.2" \
+  -a "$VER3" != "3.12.2" -a "$VER3" != "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 diff -u sqlite3.orig/src/tclsqlite.c sqlite3/src/tclsqlite.c
 --- sqlite3.orig/src/tclsqlite.c	2007-04-06 17:02:14.000000000 +0200
 +++ sqlite3/src/tclsqlite.c	2007-04-10 07:47:49.000000000 +0200
 @@ -14,6 +14,7 @@
  **
- ** $Id: mingw64-cross-build.sh,v 1.55 2015/04/12 14:09:48 chw Exp chw $
+ ** $Id: mingw64-cross-build.sh,v 1.63 2016/06/04 16:20:37 chw Exp chw $
  */
 +#ifndef NO_TCL     /* Omit this whole file if TCL is unavailable */
  #include "tcl.h"
@@ -695,7 +769,10 @@ diff -u sqlite3.orig/src/tclsqlite.c sqlite3/src/tclsqlite.c
 +#endif /* !defined(NO_TCL) */
 EOD
 
-test "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
+test "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" \
+  -o "$VER3" = "3.8.11" -o "$VER3" = "3.9.0" -o "$VER3" = "3.9.1" \
+  -o "$VER3" = "3.9.2" -o "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" \
+  -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/tclsqlite.c    2015-01-16 14:47:26.000000000 +0100
 +++ sqlite3/src/tclsqlite.c 2015-01-19 17:56:26.517386413 +0100
@@ -863,6 +940,9 @@ test "$VER3" != "3.6.21" -a "$VER3" != "3.6.22" -a "$VER3" != "3.6.23" \
   -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
   -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   -a "$VER3" != "3.8.7" -a "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" \
+  -a "$VER3" != "3.8.10" -a "$VER3" != "3.8.11" -a "$VER3" != "3.9.0" \
+  -a "$VER3" != "3.9.1" -a "$VER3" != "3.9.2" -a "$VER3" != "3.10.0" \
+  -a "$VER3" != "3.10.2" -a "$VER3" != "3.12.2" -a "$VER3" != "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c 2008-02-02 17:24:34.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c      2008-03-16 11:29:02.000000000 +0100
@@ -943,8 +1023,7 @@ EOD
 test "$VER3" = "3.6.21" -o "$VER3" = "3.6.22" -o "$VER3" = "3.6.23" \
   -o "$VER3" = "3.6.23.1" -o "$VER3" = "3.7.0" -o "$VER3" = "3.7.0.1" \
   -o "$VER3" = "3.7.1" -o "$VER3" = "3.7.2" -o "$VER3" = "3.7.3" \
-  -o "$VER3" = "3.7.4" -o "$VER3" = "3.7.5" -o "$VER3" = "3.7.5" \
-  -o "$VER3" = "3.7.6" \
+  -o "$VER3" = "3.7.4" -o "$VER3" = "3.7.5" -o "$VER3" = "3.7.6" \
   -o "$VER3" = "3.7.6.1" -o "$VER3" = "3.7.6.2" -o "$VER3" = "3.7.6.3" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c 2008-02-02 17:24:34.000000000 +0100
@@ -1009,7 +1088,10 @@ test "$VER3" != "3.7.8" -a "$VER3" != "3.7.9" -a "$VER3" != "3.7.10" \
   -a "$VER3" != "3.8.2" -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" \
   -a "$VER3" != "3.8.4.1" -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" \
   -a "$VER3" != "3.8.6" -a "$VER3" != "3.8.7" -a "$VER3" != "3.8.8" \
-  -a "$VER3" != "3.8.9" \
+  -a "$VER3" != "3.8.9" -a "$VER3" != "3.8.10" -a "$VER3" != "3.8.11" \
+  -a "$VER3" != "3.9.0" -a "$VER3" != "3.9.1" -a "$VER3" != "3.9.2" \
+  -a "$VER3" != "3.10.0" -a "$VER3" != "3.10.2" -a "$VER3" != "3.12.2" \
+  -a "$VER3" != "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_hash.c    2007-11-24 01:41:52.000000000 +0100
 +++ sqlite3/ext/fts3/fts3_hash.c 2008-03-16 11:39:57.000000000 +0100
@@ -1083,8 +1165,8 @@ test "$VER3" = "3.6.22" -o "$VER3" = "3.6.23" -o "$VER3" = "3.6.23.1" \
  #endif
 EOD
 
-test "$VER3" = "3.7.6"\
-  -o "$VER3" = "3.7.6.1" -o "$VER3" = "3.7.6.2" -o "$VER3" = "3.7.6.3" \
+test "$VER3" = "3.7.6" -o "$VER3" = "3.7.6.1" -o "$VER3" = "3.7.6.2" \
+  -o "$VER3" = "3.7.6.3" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_write.c	2011-04-12 11:44:56.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_write.c	2011-04-13 08:00:51.000000000 +0200
@@ -1353,6 +1435,9 @@ test "$VER3" != "3.8.0" -a "$VER3" != "3.8.1" -a "$VER3" != "3.8.2" \
   -a "$VER3" != "3.8.3" -a "$VER3" != "3.8.4" -a "$VER3" != "3.8.4.1" \
   -a "$VER3" != "3.8.4.2" -a "$VER3" != "3.8.5" -a "$VER3" != "3.8.6" \
   -a "$VER3" != "3.8.7" -a "$VER3" != "3.8.8" -a "$VER3" != "3.8.9" \
+  -a "$VER3" != "3.8.10" -a "$VER3" != "3.8.11" -a "$VER3" != "3.9.0" \
+  -a "$VER3" != "3.9.1" -a "$VER3" != "3.9.2" -a "$VER3" != "3.10.0" \
+  -a "$VER3" != "3.10.2" -a "$VER3" != "3.12.2" -a "$VER3" != "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/rtree/rtree.c	2008-07-16 16:43:35.000000000 +0200
 +++ sqlite3/ext/rtree/rtree.c	2008-07-17 08:59:53.000000000 +0200
@@ -1430,6 +1515,9 @@ test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" -o "$VER3" = "3.8.4.1" \
   -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" -o "$VER3" = "3.8.6" \
   -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" -o "$VER3" = "3.9.0" \
+  -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" -o "$VER3" = "3.10.0" \
+  -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_aux.c	2011-06-24 09:06:08.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_aux.c	2011-06-25 06:44:08.000000000 +0200
@@ -1479,7 +1567,10 @@ test "$VER3" = "3.7.8" -o "$VER3" = "3.7.9" -o "$VER3" = "3.7.10" \
   -o "$VER3" = "3.8.2" -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" \
   -o "$VER3" = "3.8.4.1" -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" \
   -o "$VER3" = "3.8.6" -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" \
-  -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" \
+  -o "$VER3" = "3.9.0" -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" \
+  -o "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" \
+  -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c	2011-09-19 20:46:52.000000000 +0200
 +++ sqlite3/ext/fts3/fts3.c	2011-09-20 09:47:40.000000000 +0200
@@ -1514,6 +1605,9 @@ test "$VER3" = "3.7.7" -o "$VER3" = "3.7.7.1" -o "$VER3" = "3.7.8" \
   -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" -o "$VER3" = "3.8.4.1" \
   -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" -o "$VER3" = "3.8.6" \
   -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" -o "$VER3" = "3.9.0" \
+  -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" -o "$VER3" = "3.10.0" \
+  -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3_expr.c	2011-06-24 09:06:08.000000000 +0200
 +++ sqlite3/ext/fts3/fts3_expr.c	2011-06-25 06:47:00.000000000 +0200
@@ -1635,8 +1729,8 @@ test "$VER3" = "3.7.11" -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" \
   -o "$VER3" = "3.7.13" -o "$VER3" = "3.7.14" -o "$VER3" = "3.7.14.1" \
   -o "$VER3" = "3.7.15" -o "$VER3" = "3.7.15.1" -o "$VER3" = "3.7.15.2" \
   && patch -d sqlite3 -p1 <<'EOD'
---- sqlite3.orig/src/sqlite3ext.h     2012-03-22 20:13:33.000000000 +0100
-+++ sqlite3/src/sqlite3ext.h  2012-03-22 20:13:57.000000000 +0100
+--- sqlite3.orig/src/sqlite3ext.h	2012-03-22 20:13:33.000000000 +0100
++++ sqlite3/src/sqlite3ext.h	2012-03-22 20:13:57.000000000 +0100
 @@ -236,6 +236,7 @@
    int (*blob_reopen)(sqlite3_blob*,sqlite3_int64);
    int (*vtab_config)(sqlite3*,int op,...);
@@ -1653,8 +1747,8 @@ test "$VER3" = "3.7.11" -o "$VER3" = "3.7.12" -o "$VER3" = "3.7.12.1" \
  #endif /* SQLITE_CORE */
  
  #define SQLITE_EXTENSION_INIT1     const sqlite3_api_routines *sqlite3_api = 0;
---- sqlite3.orig/src/loadext.c        2012-03-20 15:20:13.000000000 +0100
-+++ sqlite3/src/loadext.c     2012-03-22 20:16:24.000000000 +0100
+--- sqlite3.orig/src/loadext.c	2012-03-20 15:20:13.000000000 +0100
++++ sqlite3/src/loadext.c	2012-03-22 20:16:24.000000000 +0100
 @@ -378,6 +378,7 @@
    sqlite3_blob_reopen,
    sqlite3_vtab_config,
@@ -1669,12 +1763,19 @@ test "$VER3" = "3.8.0" -o "$VER3" = "3.8.1" -o "$VER3" = "3.8.2" \
   -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" -o "$VER3" = "3.8.4.1" \
   -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" -o "$VER3" = "3.8.6" \
   -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" -o "$VER3" = "3.9.0" \
+  -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" -o "$VER3" = "3.10.0" \
+  -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/loadext.c       2013-09-16 06:56:48.000000000 +0200
 +++ sqlite3/src/loadext.c   2013-09-16 06:58:14.000000000 +0200
-@@ -495,7 +495,8 @@
+@@ -495,7 +495,12 @@
      memcpy(zAltEntry, "sqlite3_", 8);
++#if SQLITE_OS_WIN
++    for(iFile=ncFile-1; iFile>=0 && zFile[iFile]!='/' && zFile[iFile]!='\\'; iFile--){}
++#else
      for(iFile=ncFile-1; iFile>=0 && zFile[iFile]!='/'; iFile--){}
++#endif
      iFile++;
 -    if( sqlite3_strnicmp(zFile+iFile, "lib", 3)==0 ) iFile += 3;
 +    if( sqlite3_strnicmp(zFile+iFile, "sqlite3_mod_", 12)==0 ) iFile += 12;
@@ -1688,7 +1789,10 @@ EOD
 test "$VER3" = "3.8.2" -o "$VER3" = "3.8.3" -o "$VER3" = "3.8.4" \
   -o "$VER3" = "3.8.4.1" -o "$VER3" = "3.8.4.2" -o "$VER3" = "3.8.5" \
   -o "$VER3" = "3.8.6" -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" \
-  -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" \
+  -o "$VER3" = "3.9.0" -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" \
+  -o "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" \
+  -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/ext/fts3/fts3.c      2014-03-26 10:26:28.000000000 +0100
 +++ sqlite3/ext/fts3/fts3.c  2014-03-26 16:54:39.000000000 +0100
@@ -1705,6 +1809,9 @@ EOD
 
 # missing windows.h for DWORD, HANDLE in threads.c
 test "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.10" -o "$VER3" = "3.8.11" -o "$VER3" = "3.9.0" \
+  -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" -o "$VER3" = "3.10.0" \
+  -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" \
   && patch -d sqlite3 -p1 <<'EOD'
 --- sqlite3.orig/src/threads.c      2014-10-17 13:38:27.000000000 +0200
 +++ sqlite3/src/threads.c   2014-10-26 13:40:26.000000000 +0100
@@ -1718,6 +1825,31 @@ test "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" -o "$VER3" = "3.8.9" \
  /* A running thread */
 EOD
 
+# tcl8.4 compatibility for mkfts5c.tcl
+test "$VER3" = "3.9.0" -o "$VER3" = "3.9.1" -o "$VER3" = "3.9.2" \
+  -o "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" \
+  -o "$VER3" = "3.13.0" \
+  && patch sqlite3/ext/fts5/tool/mkfts5c.tcl <<'EOD'
+--- mkfts5c.tcl.orig	2015-10-14 14:53:26.000000000 +0200
++++ mkfts5c.tcl	2015-10-15 08:19:25.000000000 +0200
+@@ -60,7 +60,8 @@
+ 
+   set L [split [readfile [file join $top manifest]]] 
+   set date [lindex $L [expr [lsearch -exact $L D]+1]]
+-  set date [string range $date 0 [string last . $date]-1]
++  set dend [expr [string last . $date]-1]
++  set date [string range $date 0 $dend]
+   set date [string map {T { }} $date]
+ 
+   return "fts5: $date $uuid"
+EOD
+
+# tcl8.4 compatibility for some tools
+test "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" -o "$VER3" = "3.12.2" \
+  -o "$VER3" = "3.13.0" \
+  && perl -pi -e 's/ rb\]/ r\]/g' sqlite3/tool/mkopcodec.tcl \
+      sqlite3/tool/tostr.tcl sqlite3/tool/addopcodes.tcl
+
 echo "========================"
 echo "Cleanup before build ..."
 echo "========================"
@@ -1778,7 +1910,7 @@ if test -r sqlite3/sqlite3.c -a -f "$WITH_SEE" ; then
     unset SQLITE3_EXE
 fi
 test "$VER3" = "3.8.6" -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" \
-  -o "$VER3" = "3.8.9" \
+  -o "$VER3" = "3.8.9" -o "$VER3" = "3.8.10" \
   && patch sqlite3/sqlite3.c <<'EOD'
 --- sqlite3.orig/sqlite3.c      2014-09-14 15:02:38.000000000 +0200
 +++ sqlite3/sqlite3.c   2014-09-14 15:03:02.000000000 +0200
@@ -1792,6 +1924,22 @@ test "$VER3" = "3.8.6" -o "$VER3" = "3.8.7" -o "$VER3" = "3.8.8" \
  #ifndef access
  # define access(f,m) _access((f),(m))
 EOD
+test "$VER3" = "3.8.11" -o "$VER3" = "3.9.0" -o "$VER3" = "3.9.1" \
+  -o "$VER3" = "3.9.2" -o "$VER3" = "3.10.0" -o "$VER3" = "3.10.2" \
+  -o "$VER3" = "3.12.2" -o "$VER3" = "3.13.0" \
+  && patch sqlite3/sqlite3.c <<'EOD'
+--- sqlite3.c.orig      2015-09-18 17:17:58.000000000 +0200
++++ sqlite3.c   2015-09-18 17:50:01.000000000 +0200
+@@ -128353,7 +128353,7 @@
+ 
+ #if defined(_WIN32) || defined(WIN32)
+ # include <io.h>
+-/* # include <fcntl.h> */
++# include <fcntl.h>
+ # define isatty(h) _isatty(h)
+ # ifndef access
+ #  define access(f,m) _access((f),(m))
+EOD
 if test -n "$SQLITE_DLLS" ; then
     make -C sqlite3 -f ../mf-sqlite3.mingw64-cross sqlite3.dll
 fi
